From 0a9ef31f555e4f08f28345fd5420b709c5886d37 Mon Sep 17 00:00:00 2001
From: Jim Collins <github@collins-fam.com>
Date: Wed, 26 Jun 2013 16:40:36 -0400
Subject: [PATCH] ldap: only update shadowLastChange when password change is successful

https://fedorahosted.org/sssd/ticket/1999

ldap_auth.c code which was added to SSSD for updating the shadowLastChange
when "ldap_chpass_update_last_change" option is enabled updates
shadowLastChange even when the PAM password change status reports failure.

We should only update shadowLastChange on PAM password change success or we
open up a work around for users to avoid changing their passwords
periodically as required by policy. The user simply attempts to change
password, fails by trying to set new password which invalid (denied due
to password history check) yet shadowLastChange is updated, avoiding their
need to actually change the password they are using.
---
 src/providers/ldap/ldap_auth.c |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/src/providers/ldap/ldap_auth.c b/src/providers/ldap/ldap_auth.c
index 58cc2d356d0e2c032f05328247540ba1a556b8ca..ffe7f033a6fb520f289f127962089f19c90f90a3 100644
--- a/src/providers/ldap/ldap_auth.c
+++ b/src/providers/ldap/ldap_auth.c
@@ -908,7 +908,7 @@ static void sdap_pam_chpass_done(struct tevent_req *req)
         }
     }
 
-    if (dp_opt_get_bool(state->ctx->opts->basic,
+    if (state->pd->pam_status == PAM_SUCCESS && dp_opt_get_bool(state->ctx->opts->basic,
                         SDAP_CHPASS_UPDATE_LAST_CHANGE)) {
         lastchanged_name = state->ctx->opts->user_map[SDAP_AT_SP_LSTCHG].name;
 
-- 
1.7.1

